@@ -74,7 +74,7 @@ def download_by_name(source, type, fetch_missing_hugo=True):
     """
     if source in ["xena", "Xena", "UCSC", "ucsc"]:
         type_dict = {'Acute Myeloid Leukemia':'LAML','Adrenocortical Cancer':'ACC', 'Bile Duct Cancer':'CHOL', 'Bladder Cancer':'BLCA', 'Breast Cancer':'BRCA',
-                     'Cervical Cancer':'CESC', 'Colon and Rectal Cancer':'COADRED', 'Colon Cancer':'COAD', 'Endometrioid Cancer':'UCEC', 'Esophageal Cancer':'ESCA',
+                     'Cervical Cancer':'CESC', 'Colon and Rectal Cancer':'COADREAD', 'Colon Cancer':'COAD', 'Endometrioid Cancer':'UCEC', 'Esophageal Cancer':'ESCA',
                      'Glioblastoma':'GBM', 'Head and Neck Cancer':'HNSC', 'Kidney Chromophobe':'KICH', 'Kidney Clear Cell Carcinoma':'KIRC', 'Kidney Papillary Cell Carcinoma':'KIRP',
                      'Large B-cell Lymphoma':'DLBC', 'Liver Cancer':'LIHC', 'Lower Grade Glioma':'LGG', 'Lower Grade Glioma and Glioblastoma':'GBMLGG', 'Lung Adenocarcinoma':'LUAD',
                      'Lung Cancer':'LUNG', 'Lung Squamous Cell Carcinoma':'LUSC', 'Melanoma':'SKCM', 'Mesothelioma':'MESO', 'Ocular Melanomas':'UVM', 'Ovarian Cancer':'OV',
@@ -85,11 +85,11 @@ def download_by_name(source, type, fetch_missing_hugo=True):
         else:
             raise ValueError("type {!r} not available from UCSC Xena".format(type))
         # Download and return:
-        data = download_from_xena(url="https://tcga.xenahubs.net/download/TCGA."+urlcode+".sampleMap/HiSeqV2.gz", fetch_missing_hugo=fetch_missing_hugo)
+        data = download_from_xena(url="https://tcga-xena-hub.s3.us-east-1.amazonaws.com/latest/TCGA."+urlcode+".sampleMap/HiSeqV2.gz", fetch_missing_hugo=fetch_missing_hugo)
         return data
-    elif source in ["cbio", "CbioPortal", "cbioportal"]:
+    elif source in ["cbio", "CbioPortal", "cbioportal", "cBioPortal"]:
         type_dict = {'Acute Myeloid Leukemia':'laml','Adrenocortical Carcinoma':'acc', 'Bladder Urothelial Carcinoma':'blca', 'Brain Lower Grade Glioma':'lgg', 'Breast Invasive Carcinoma':'brca',
-                     'Cervical Squamous Cell Carcinoma':'cesc', 'Cholangiocarcinoma':'chol', 'Colorectal Adenocarcinoma':'coadred', 'Diffuse Large B-Cell Lymphoma':'dlbc', 'Esophageal Adenocarcinoma':'esca',
+                     'Cervical Squamous Cell Carcinoma':'cesc', 'Cholangiocarcinoma':'chol', 'Colorectal Adenocarcinoma':'coadread', 'Diffuse Large B-Cell Lymphoma':'dlbc', 'Esophageal Adenocarcinoma':'esca',
                      'Glioblastoma Multiforme':'gbm', 'Head and Neck Squamous Cell Carcinoma':'hnsc', 'Kidney Chromophobe':'kich', 'Kidney Renal Clear Cell Carcinoma':'kirc', 'Kidney Renal Papillary Cell Carcinoma':'kirp',
                      'Liver Hepatocellular Carcinoma':'lihc', 'Lung Adenocarcinoma':'luad', 'Lung Squamous Cell Carcinoma':'lusc', 'Mesothelioma':'meso', 'Ovarian Serous Cystadenocarcinoma':'ov', 'Pancreatic Adenocarcinoma':'paad',
                      'Pheochromocytoma and Paraganglioma':'pcpg', 'Prostate Adenocarcinoma':'prad', 'Sarcoma':'sarc', 'Skin Cutaneous Melanoma':'skcm', 'Stomach Adenocarcinoma':'stad', 'Testicular Germ Cell Tumors':'tgct',
@@ -99,14 +99,14 @@ def download_by_name(source, type, fetch_missing_hugo=True):
         else:
             raise ValueError("type {!r} not available from CbioPortal".format(type))
         # Download and return:
-        data = download_from_cbio(url="http://download.cbioportal.org/"+urlcode+"_tcga_pan_can_atlas_2018.tar.gz", fetch_missing_hugo=fetch_missing_hugo)
+        data = download_from_cbio(url="https://cbioportal-datahub.s3.amazonaws.com/"+urlcode+"_tcga_pan_can_atlas_2018.tar.gz", fetch_missing_hugo=fetch_missing_hugo)
         return data
     else:
         raise ValueError("source ({!r}) must be 'xena' or 'cbioportal'".format(source))
 
 
 
-def download_from_cbio(url="http://download.cbioportal.org/uvm_tcga_pan_can_atlas_2018.tar.gz", save_location=get_td_Home()+"data/downloaded/", delete_after=False, fetch_missing_hugo=True):
+def download_from_cbio(url="https://cbioportal-datahub.s3.amazonaws.com/uvm_tcga_pan_can_atlas_2018.tar.gz", save_location=get_td_Home()+"data/downloaded/", delete_after=False, fetch_missing_hugo=True):
     """
     Function to download data directly from cbioportal and read it in as a pandas df.
         Inputs:
@@ -122,7 +122,7 @@ def download_from_cbio(url="http://download.cbioportal.org/uvm_tcga_pan_can_atla
     import os
 
     # Check if file already downloaded, if not, download it:
-    file = save_location+url.replace('http://download.cbioportal.org/','')
+    file = save_location+url.replace('https://cbioportal-datahub.s3.amazonaws.com/','')
     if not os.path.exists(file):
         # Download file and save it locally:
         print("Downloading data from cbioportal...")
@@ -131,14 +131,14 @@ def download_from_cbio(url="http://download.cbioportal.org/uvm_tcga_pan_can_atla
     folder = file.replace(".tar.gz","")
     if file.endswith("tar.gz") and not os.path.exists(folder):
         tar = tarfile.open(file, "r:gz")
-        tar.extract("data_RNA_Seq_v2_expression_median.txt", path=folder)
+        tar.extract(folder.split("/")[-1]+"/data_RNA_Seq_v2_expression_median.txt", path=save_location)
         # tar.extractall(folder.strip(".tar.gz"))
         tar.close()
     # Read in data:
     return read_rna_file(folder+"/data_RNA_Seq_v2_expression_median.txt", fetch_missing_hugo=fetch_missing_hugo)
 
 
-def download_from_xena(url="https://tcga.xenahubs.net/download/TCGA.UCS.sampleMap/HiSeqV2.gz", save_location=get_td_Home()+"data/downloaded/", delete_after=False, fetch_missing_hugo=True):
+def download_from_xena(url="https://tcga-xena-hub.s3.us-east-1.amazonaws.com/latest/TCGA.UCS.sampleMap/HiSeqV2.gz", save_location=get_td_Home()+"data/downloaded/", delete_after=False, fetch_missing_hugo=True):
     """
     Function to download data directly from TCGA Xena Hub and read it in as a pandas df.
         Inputs:
@@ -442,7 +442,7 @@ def variance_threshold_selector(data, threshold=0.5):
     return data_red.T
 
 
-def read_ssGSEA_up_genes(filepath=get_td_Home()+'data/Gene_sets.csv'):
+def read_ssGSEA_up_genes(file_path=get_td_Home()+'data/Gene_sets.csv'):
     """
     Function to read in csv file containing the gene sets from the ssGSEA paper
     Inputs:
@@ -453,29 +453,32 @@ def read_ssGSEA_up_genes(filepath=get_td_Home()+'data/Gene_sets.csv'):
     """
     import pandas as pd
 
-    gene_sets = pd.read_csv(filepath)
+    gene_sets = pd.read_csv(file_path)
     up_genes = {}
     for cell in gene_sets['Cell type'].unique():
         up_genes[cell] = gene_sets[gene_sets['Cell type'] == cell]['Symbol'].tolist()
 
     return up_genes
 
-def read_geneset(filepath):
+def read_geneset(file_path=get_td_Home()+"data/LM22_up_genes.csv"):
     """
         Function to read in a custom csv file containing the up or down regulated
             genes for each cell type
         Inputs:
-            - path to correct csv file. File should have columns named for each cell type,
-            and rows should contain Hugo Symbols for genes to be considered as up (or down)
+            - file_path: string. Relative or full path to signature matrix file.
+            File should have columns named for each cell type, and rows should
+            contain Hugo Symbols for genes to be considered as up (or down)
             regulated for that cell type. If not all cell types have the same number of up(down)
             regulated genes, excess rows in each column should be coded as "NaN"
+                If no file_path given, the up-regulated gene set derived in
+                Le et al. (2020) is assumed.
         Outputs:
             - dictionary. Keys are the column names of the given csv file (cell types),
                 values are a list of up (down) regulated genes for that cell type
     """
     import pandas as pd
     import numpy as np
-    gene_sets = pd.read_csv(filepath)
+    gene_sets = pd.read_csv(file_path)
     chosen_genes = {} # up or down genes
     for cell in gene_sets.columns.unique():
         chosen_genes[cell] = list(gene_sets[cell].dropna())
